@@ -130,7 +130,7 @@ class DataSyncClient(BaseClient):
 
     def cancel_task_execution(self, *, TaskExecutionArn: str) -> Dict[str, Any]:
         """
-        Cancels execution of a task.
+        Stops an DataSync task execution that's in progress.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#cancel_task_execution)
@@ -155,7 +155,7 @@ class DataSyncClient(BaseClient):
         SecurityGroupArns: Sequence[str] = ...
     ) -> CreateAgentResponseTypeDef:
         """
-        Activates an DataSync agent that you have deployed on your host.
+        Activates an DataSync agent that you have deployed in your storage environment.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_agent)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_agent)
@@ -222,7 +222,8 @@ class DataSyncClient(BaseClient):
         Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationFsxOpenZfsResponseTypeDef:
         """
-        Creates an endpoint for an Amazon FSx for OpenZFS file system.
+        Creates an endpoint for an Amazon FSx for OpenZFS file system that DataSync can
+        access for a transfer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_open_zfs)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_open_zfs)
@@ -298,7 +299,8 @@ class DataSyncClient(BaseClient):
         Subdirectory: str = ...,
         AccessKey: str = ...,
         SecretKey: str = ...,
-        Tags: Sequence[TagListEntryTypeDef] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...,
+        ServerCertificate: Union[str, bytes, IO[Any], StreamingBody] = ...
     ) -> CreateLocationObjectStorageResponseTypeDef:
         """
         Creates an endpoint for an object storage system that DataSync can access for a
@@ -319,7 +321,8 @@ class DataSyncClient(BaseClient):
         Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationS3ResponseTypeDef:
         """
-        Creates an endpoint for an Amazon S3 bucket.
+        Creates an endpoint for an Amazon S3 bucket that DataSync can access for a
+        transfer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_s3)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_s3)
@@ -383,7 +386,7 @@ class DataSyncClient(BaseClient):
 
     def delete_task(self, *, TaskArn: str) -> Dict[str, Any]:
         """
-        Deletes a task.
+        Deletes an DataSync task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_task)
@@ -410,8 +413,8 @@ class DataSyncClient(BaseClient):
         self, *, LocationArn: str
     ) -> DescribeLocationFsxLustreResponseTypeDef:
         """
-        Returns metadata about an Amazon FSx for Lustre location, such as information
-        about its path.
+        Provides details about how an DataSync location for an Amazon FSx for Lustre
+        file system is configured.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_lustre)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_lustre)
@@ -432,8 +435,8 @@ class DataSyncClient(BaseClient):
         self, *, LocationArn: str
     ) -> DescribeLocationFsxOpenZfsResponseTypeDef:
         """
-        Returns metadata about an Amazon FSx for OpenZFS location, such as information
-        about its path.
+        Provides details about how an DataSync location for an Amazon FSx for OpenZFS
+        file system is configured.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_open_zfs)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_open_zfs)
@@ -554,7 +557,7 @@ class DataSyncClient(BaseClient):
         self, *, ResourceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        Returns all the tags associated with a specified resource.
+        Returns all the tags associated with an Amazon Web Services resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_tags_for_resource)
@@ -590,10 +593,11 @@ class DataSyncClient(BaseClient):
         TaskArn: str,
         OverrideOptions: OptionsTypeDef = ...,
         Includes: Sequence[FilterRuleTypeDef] = ...,
-        Excludes: Sequence[FilterRuleTypeDef] = ...
+        Excludes: Sequence[FilterRuleTypeDef] = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> StartTaskExecutionResponseTypeDef:
         """
-        Starts a specific invocation of a task.
+        Starts an DataSync task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.start_task_execution)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#start_task_execution)
@@ -603,7 +607,7 @@ class DataSyncClient(BaseClient):
         self, *, ResourceArn: str, Tags: Sequence[TagListEntryTypeDef]
     ) -> Dict[str, Any]:
         """
-        Applies a key-value pair to an Amazon Web Services resource.
+        Applies a *tag* to an Amazon Web Services resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#tag_resource)
@@ -611,7 +615,7 @@ class DataSyncClient(BaseClient):
 
     def untag_resource(self, *, ResourceArn: str, Keys: Sequence[str]) -> Dict[str, Any]:
         """
-        Removes a tag from an Amazon Web Services resource.
+        Removes tags from an Amazon Web Services resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#untag_resource)
@@ -675,11 +679,12 @@ class DataSyncClient(BaseClient):
         Subdirectory: str = ...,
         AccessKey: str = ...,
         SecretKey: str = ...,
-        AgentArns: Sequence[str] = ...
+        AgentArns: Sequence[str] = ...,
+        ServerCertificate: Union[str, bytes, IO[Any], StreamingBody] = ...
     ) -> Dict[str, Any]:
         """
-        Updates some of the parameters of a previously created location for self-managed
-        object storage server access.
+        Updates some parameters of an existing object storage location that DataSync
+        accesses for a transfer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_object_storage)
