@@ -588,6 +588,7 @@ _OptionalUpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
         "AccessKey": str,
         "SecretKey": str,
         "AgentArns": Sequence[str],
+        "ServerCertificate": Union[str, bytes, IO[Any], StreamingBody],
     },
     total=False,
 )
@@ -693,6 +694,7 @@ _OptionalCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
         "AccessKey": str,
         "SecretKey": str,
         "Tags": Sequence[TagListEntryTypeDef],
+        "ServerCertificate": Union[str, bytes, IO[Any], StreamingBody],
     },
     total=False,
 )
@@ -843,6 +845,7 @@ DescribeLocationObjectStorageResponseTypeDef = TypedDict(
         "ServerProtocol": ObjectStorageServerProtocolType,
         "AgentArns": List[str],
         "CreationTime": datetime,
+        "ServerCertificate": bytes,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1203,6 +1206,7 @@ _OptionalStartTaskExecutionRequestRequestTypeDef = TypedDict(
         "OverrideOptions": OptionsTypeDef,
         "Includes": Sequence[FilterRuleTypeDef],
         "Excludes": Sequence[FilterRuleTypeDef],
+        "Tags": Sequence[TagListEntryTypeDef],
     },
     total=False,
 )
@@ -1329,6 +1333,7 @@ DescribeTaskExecutionResponseTypeDef = TypedDict(
         "BytesWritten": int,
         "BytesTransferred": int,
         "Result": TaskExecutionResultDetailTypeDef,
+        "BytesCompressed": int,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
